From 3ef766851af597facd4aef32e5fe0c962a0056e3 Mon Sep 17 00:00:00 2001 From: Ovahlord Date: Fri, 28 Feb 2025 20:41:56 +0100 Subject: [PATCH] Core/Zmq: reduced thread sleep time from 50ms down to 1ms --- src/server/ipc/ZmqMux.cpp | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-) diff --git a/src/server/ipc/ZmqMux.cpp b/src/server/ipc/ZmqMux.cpp index 816e9b4d91..63d32568a1 100644 --- a/src/server/ipc/ZmqMux.cpp +++ b/src/server/ipc/ZmqMux.cpp @@ -56,7 +56,7 @@ void ZmqMux::Run() { for (;;) { - std::this_thread::sleep_for(std::chrono::milliseconds(50)); + std::this_thread::sleep_for(std::chrono::milliseconds(1)); if (!_poller->poll()) break;